==> cms_content_sync-8.x-1.29.tar.gz: cms_content_sync/src/Plugin/cms_content_sync/entity_handler/DefaultCropHandler.php <==
<?php

namespace Drupal\cms_content_sync\Plugin\cms_content_sync\entity_handler;

use Drupal\cms_content_sync\ExportIntent;
use Drupal\cms_content_sync\ImportIntent;
use Drupal\cms_content_sync\MissingDependencyManager;
use Drupal\cms_content_sync\Plugin\EntityHandlerBase;

/**
 * Class DefaultCropHandler, providing a minimalistic implementation for the
 * crop entity type.
 *
 * @EntityHandler(
 *   id = "cms_content_sync_crop_handler",
 *   label = @Translation("Default Crop"),
 *   weight = 90
 * )
 *
 * @package Drupal\cms_content_sync\Plugin\cms_content_sync\entity_handler
 */
class DefaultCropHandler extends EntityHandlerBase {

  const USER_REVISION_PROPERTY = 'revision_uid';

  /**
   * @inheritdoc
   */
  public static function supports($entity_type, $bundle) {
    return $entity_type == 'crop';
  }

  /**
   * @inheritdoc
   */
  public function getHandlerSettings($current_values, $type = 'both') {
    return [];
  }

  /**
   * @inheritdoc
   */
  public function getAllowedExportOptions() {
    return [
      ExportIntent::EXPORT_DISABLED,
      ExportIntent::EXPORT_AS_DEPENDENCY,
    ];
  }

  /**
   * @inheritdoc
   */
  public function getAllowedImportOptions() {
    return [
      ImportIntent::IMPORT_DISABLED,
      ImportIntent::IMPORT_AS_DEPENDENCY,
    ];
  }

  /**
   * @inheritdoc
   */
  public function import(ImportIntent $intent) {
    /* @var \Drupal\file\FileInterface[] $files */
    $files = \Drupal::entityTypeManager()
      ->getStorage('file')
      ->loadByProperties(['uri' => $intent->getField('uri')[0]['value']]);

    // Unset the entity_id field so that it gets automatically set during
    // the entity creation.
    if (!count($files)) {
      $intent->setField('entity_id', NULL);
    }
    else {
      /**
       * @var \Drupal\file\FileInterface $file
       */
      $file = reset($files);
      $this->deleteExistingCrop($intent, $file);
      $intent->setField('entity_id', $file->id());
    }

    if (!parent::import($intent)) {
      return FALSE;
    }

    if (!count($files)) {
      MissingDependencyManager::saveUnresolvedDependency(
        'file',
        $intent->getField('uri')[0]['value'],
        $intent->getEntity(),
        $intent->getReason(),
        'entity_id'
      );
    }

    return TRUE;
  }

  /**
   * @inheritdoc
   */
  public function getAllowedPreviewOptions() {
    return [
      'table' => 'Table',
      'preview_mode' => 'Preview mode',
    ];
  }

  /**
   * Delete already existing Crop entity.
   *
   * @param $file
   */
  private function deleteExistingCrop(ImportIntent $intent, $file) {
    $moduleHandler = \Drupal::service('module_handler');
    if ($moduleHandler->moduleExists('focal_point')) {
      /**
       * @var \Drupal\focal_point\FocalPointManagerInterface $focal_point_manager
       */
      $focal_point_manager = \Drupal::service('focal_point.manager');
      $crop = $focal_point_manager->getCropEntity($file, 'focal_point');

      if ($crop && $crop->uuid() != $intent->getUuid()) {
        $crop->delete();
      }
    }
  }

}

==> cms_content_sync-8.x-1.33.tar.gz: cms_content_sync/src/Plugin/cms_content_sync/entity_handler/DefaultCropHandler.php <==
<?php

namespace Drupal\cms_content_sync\Plugin\cms_content_sync\entity_handler;

use Drupal\cms_content_sync\PushIntent;
use Drupal\cms_content_sync\PullIntent;
use Drupal\cms_content_sync\MissingDependencyManager;
use Drupal\cms_content_sync\Plugin\EntityHandlerBase;

/**
 * Class DefaultCropHandler, providing a minimalistic implementation for the
 * crop entity type.
 *
 * @EntityHandler(
 *   id = "cms_content_sync_crop_handler",
 *   label = @Translation("Default Crop"),
 *   weight = 90
 * )
 *
 * @package Drupal\cms_content_sync\Plugin\cms_content_sync\entity_handler
 */
class DefaultCropHandler extends EntityHandlerBase {

  const USER_REVISION_PROPERTY = 'revision_uid';

  /**
   * @inheritdoc
   */
  public static function supports($entity_type, $bundle) {
    return $entity_type == 'crop';
  }

  /**
   * @inheritdoc
   */
  public function getHandlerSettings($current_values, $type = 'both') {
    return [];
  }

  /**
   * @inheritdoc
   */
  public function getAllowedPushOptions() {
    return [
      PushIntent::PUSH_DISABLED,
      PushIntent::PUSH_AS_DEPENDENCY,
    ];
  }

  /**
   * @inheritdoc
   */
  public function getAllowedPullOptions() {
    return [
      PullIntent::PULL_DISABLED,
      PullIntent::PULL_AS_DEPENDENCY,
    ];
  }

  /**
   * @inheritdoc
   */
  public function pull(PullIntent $intent) {
    /* @var \Drupal\file\FileInterface[] $files */
    $files = \Drupal::entityTypeManager()
      ->getStorage('file')
      ->loadByProperties(['uri' => $intent->getField('uri')[0]['value']]);

    // Unset the entity_id field so that it gets automatically set during
    // the entity creation.
    if (!count($files)) {
      $intent->setField('entity_id', NULL);
    }
    else {
      /**
       * @var \Drupal\file\FileInterface $file
       */
      $file = reset($files);
      $this->deleteExistingCrop($intent, $file);
      $intent->setField('entity_id', $file->id());
    }

    if (!parent::pull($intent)) {
      return FALSE;
    }

    if (!count($files)) {
      MissingDependencyManager::saveUnresolvedDependency(
        'file',
        $intent->getField('uri')[0]['value'],
        $intent->getEntity(),
        $intent->getReason(),
        'entity_id'
      );
    }

    return TRUE;
  }

  /**
   * @inheritdoc
   */
  public function getAllowedPreviewOptions() {
    return [
      'table' => 'Table',
      'preview_mode' => 'Preview mode',
    ];
  }

  /**
   * Delete already existing Crop entity.
   *
   * @param $file
   */
  private function deleteExistingCrop(PullIntent $intent, $file) {
    $moduleHandler = \Drupal::service('module_handler');
    if ($moduleHandler->moduleExists('focal_point')) {
      /**
       * @var \Drupal\focal_point\FocalPointManagerInterface $focal_point_manager
       */
      $focal_point_manager = \Drupal::service('focal_point.manager');
      $crop = $focal_point_manager->getCropEntity($file, 'focal_point');

      if ($crop && $crop->uuid() != $intent->getUuid()) {
        $crop->delete();
      }
    }
  }

}
